addable

package
v0.0.0-...-472ce55 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2020 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Add

func Add(a interface{}, b interface{}) (interface{}, error)

Add returns Iterator in case it's possible to create one from sent object, otherwise returns error.

Types

type Addable

type Addable interface {
	Add(Addable) (Addable, error)
}

Addable is the interface which when implemented by structs, they can be added together into single object For basic types, add logic inside below given Add func.

Jump to