Discover Packages
github.com/Ashish-Bansal/redis-spectacles
pkg
addable
package
Version:
v0.0.0-...-472ce55
Opens a new window with list of versions in this module.
Published: May 25, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func Add(a interface{}, b interface{}) (interface{}, error )
Add returns Iterator in case it's possible to create one from sent object, otherwise returns error.
Addable is the interface which when implemented by structs, they can be added together into single object
For basic types, add logic inside below given Add func.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.